@@ -5,7 +5,7 @@ use strict;
 use Text::Markup::None;
 use Carp;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 my %_PARSER_FOR;
 my %REGEX_FOR = (
@@ -17,6 +17,7 @@ my %REGEX_FOR = (
     trac          => qr{tra?c},
     mediawiki     => qr{(?:m(?:edia)?)?wiki},
     rest          => qr{re?st},
+    asciidoc      => qr{a(?:sc(?:iidoc)?|doc)?},
 );
 
 sub register {
@@ -117,6 +118,8 @@ This distribution includes support for a number of markup formats:
 
 =over
 
+=item * L<Asciidoc|http://www.methods.co.nz/asciidoc/>
+
 =item * L<HTML|http://whatwg.org/html>
 
 =item * L<Markdown|http://daringfireball.net/projects/markdown/>
